class to represent a tree from the ATC hierarchy
atctree-class.Rdclass to represent a tree from the ATC hierarchy
Slots
nodenode id
pnodeparent node id
labATC code
plabparent ATC code
textATC textual info
levlevel of each node (root node is 0)
schemaone of 'none', 'full', 'anatomical', 'therapeutic', 'chemical'
whichlevssubset of integers 1:5; should correspond to schema
Nnodenumber of nodes in the tree excluding root node
Nlevnumber of levels in the tree excluding root node